pragma solidity ^0.4.0;

import "./AbstractIdentity.sol";


contract Identity is AbstractIdentity {

	/**
	 * sets the backend stores for the identity contract
	 * will throw if either store is already set
	 * will throw if contract is not owner of both stores
	 * @param _identityregistrar identity store (ENS registrar)
	 * @param _signaturestore signature store
	 */
	function setStores(address _identityregistrar, address _signaturestore) {
		address empty;
		require(identityRegistrar == empty);
		require(signatureStore == empty);
		IdentityRegistrar r = IdentityRegistrar(_identityregistrar);
		SignatureStore s = SignatureStore(_signaturestore);
		require(r.isOwned());
		require(s.isOwned());
		identityRegistrar = r;
		signatureStore = s;
	}
	/**
	 * for upgrade
	 * transfer store ownership to new identity contract
	 * @param _newidentity address of new contract
	 */
	function transferStores(address _newidentity) onlyowner {
		identityRegistrar.setOwner(_newidentity);
		signatureStore.setOwner(_newidentity);
	}
	/**
	 * Register an metaid ens node,
	 * or change the owner of an existing registration.
	 * @param _node The hash of the label to register.
	 * @param _newowner The ethereum address of the new owner.
	 */
	function register(bytes32 _node, address _newowner) {
		identityRegistrar.register(_node, _newowner);
		Registered(_node, _newowner);
	}
	/**
	 * Add a new detached signature content hash to a metadata item content hash of a metaid
	 * @param _signer metaid of signer
	 * @param _target metaid of owner of metadata item
	 * @param _item_id_digest metadata item id
	 * @param _item_digest content hash of metadata item
	 * @param _signature_digest detached signature hash
	 */
	function setSignature(bytes32 _signer, bytes32 _target, bytes32 _item_id_digest, bytes32 _item_digest, bytes32 _signature_digest) {
		signatureStore.setSignature(_signer, _target, _item_id_digest, _item_digest, _signature_digest);
		Signed(_target, _item_id_digest, _signature_digest);
	}

	/**
	 * Get number of members in signatures array for a metadata item of a metaid
	 * @param _target metaid of owner of metadata item
	 * @param _item_id_digest content hash of metadata item
	 * @return number of signatures in array
	 */
	function getSignatureCount(bytes32 _target, bytes32 _item_id_digest) constant returns(uint256) {
		return signatureStore.getSignatureCount(_target, _item_id_digest);
	}

	/**
	 * Get signature at index in signature array for a metadata item of a metaid
	 * @param _target metaid of owner of metadata item
	 * @param _item_id_digest content hash of metadata item
	 * @param _idx index in signature array to detached signature content hash
	 * @return metaid of signer, metadata item content hash, detached signature content hash
	 */
	function getSignatureByIndex(bytes32 _target, bytes32 _item_id_digest, uint32 _idx) constant returns(bytes32, bytes32, bytes32) {
		return signatureStore.getSignatureByIndex(_target, _item_id_digest, _idx);
	}
}
