pragma solidity ^0.4.11;

import "Identity.sol";
import "AbstractIdentity.sol";
import "IdentityRegistrar.sol";
import "SignatureStore.sol";


contract IdentityController {
	bytes32 constant IDMETA_NAMEHASH = 0x339dc3405c34e8bf7c46232cf4b95d758a68a5adf65d5392289f1958574a850a; // namehash("id.meta")
	address public current;

	event IdentityUpgraded(address upgradedidentity);
	event IdentityCreated(address createdidentity);
	
	/**
	 * creates new identity contract, new registrar and new signaturestore
	 * @param _ens address of ens registry
	 */
	function createIdentity(address _ens) {
		IdentityRegistrar identityregistrar = new IdentityRegistrar(AbstractENS(_ens), IDMETA_NAMEHASH);
		SignatureStore signaturestore = new SignatureStore();
		Identity newidentity = new Identity();
		identityregistrar.setOwner(newidentity);
		signaturestore.setOwner(newidentity);
		newidentity.setStores(identityregistrar, signaturestore);
		current = newidentity;
		IdentityCreated(current);
	}

	/**
	 * upgrades contract with existing registrar and signaturestore
	 * owner of identity contract must have been set to this controller instance
	 * @param _identity address of identity contract to upgrade to
	 */
	function upgradeIdentity(address _identity) {
		AbstractIdentity newidentity = AbstractIdentity(_identity);
		require(newidentity.isOwned());
		AbstractIdentity oldidentity = AbstractIdentity(current);
		IdentityRegistrar identityregistrar = IdentityRegistrar(oldidentity.identityRegistrar());
		SignatureStore signaturestore = SignatureStore(oldidentity.signatureStore());
		oldidentity.transferStores(newidentity);
		newidentity.setStores(identityregistrar, signaturestore);
		current = newidentity;
		IdentityUpgraded(current);
	}
}
