pragma solidity ^0.4.0;

import './lib/ownedextended.sol';
import './lib/AbstractENS.sol';


// modeled on https://github.com/ethereum/ens/blob/master/contracts/FIFSRegistrar.sol
contract IdentityRegistrar is ownedextended {
	AbstractENS ens;
	bytes32 rootNode;
	
	modifier onlyNodeOwner(bytes32 subnode) {
		var node = sha3(rootNode, subnode);
		var currentOwner = ens.owner(node);
		if (currentOwner != 0 && currentOwner != msg.sender) {
			revert();
		}
		_;
	}

	/**
	 * Constructor.
	 * @param _ensAddr The address of the ENS registry.
	 * @param _node The node that this registrar administers.
	 */
	function IdentityRegistrar(AbstractENS _ensAddr, bytes32 _node) {
		ens = _ensAddr;
		rootNode = _node;
	}

	/**
	 * Register a name, or change the owner of an existing registration.
	 * @param _subnode The hash of the label to register.
	 * @param _owner The address of the new owner.
	 */
	function register(bytes32 _subnode, address _owner) onlyNodeOwner(rootNode) {
		require(ens.owner(sha3(rootNode, _subnode)) == 0);
		ens.setSubnodeOwner(rootNode, _subnode, _owner);
	}

	/**
	 * Used for upgrade, changes parent owner
	 * @param _newowner address of new parent contract
	 */
	function transfer(address _newowner) onlyowner {
		owner = _newowner;
	}
}
