pragma solidity ^0.4.11;

import './lib/AbstractENS.sol';


// modeled on https://github.com/ethereum/ens/blob/master/contracts/PublicResolver.sol
contract IdentityResolver {

	bytes4 constant INTERFACE_META_ID = 0x01ffc9a7;
	bytes4 constant CONTENT_INTERFACE_ID = 0xd8389dc5;

	event ContentChanged(bytes32 indexed node, bytes32 hash);

	AbstractENS ens;

	struct Record {
		address addr;
		bytes32 content;
	}	

	mapping(bytes32=>Record) records;

	modifier only_owner(bytes32 node) {
		if (ens.owner(node) != msg.sender) {
			revert();
		}
		_;
	}

	function IdentityResolver(address _ens) {
		ens = AbstractENS(_ens);
	}

	// EIP 165
	function supportsInterface(bytes4 interfaceID) constant returns (bool) {
		return 	interfaceID == INTERFACE_META_ID ||
			interfaceID == CONTENT_INTERFACE_ID;
	}

	/**
	* Returns the content hash associated with an ENS node.
	* Note that this resource type is not standardized, and will likely change
	* in future to a resource type based on multihash.
	* @param _node The ENS node to query.
	* @return The associated content hash.
	*/
	function content(bytes32 _node) constant returns (bytes32 ret) {
		ret = records[_node].content;
	}
	/**
	* Sets the content hash associated with an ENS node.
	* May only be called by the owner of that node in the ENS registry.
	* Note that this resource type is not standardized, and will likely change
	* in future to a resource type based on multihash.
	* @param _node The node to update.
	* @param _hash The content hash to set
	*/
	function setContent(bytes32 _node, bytes32 _hash) only_owner(_node) {
		records[_node].content = _hash;
		ContentChanged(_node, _hash);
	}
}
