pragma solidity ^0.4.11;

import "./lib/ownedextended.sol";


contract SignatureStore is ownedextended {
	struct Signature {
		bytes32 signer; // meta id of signer
		bytes32 itemDigest; // metadata item being signed
		bytes32 signatureDigest; // detached signature
	}
	mapping(bytes32 => mapping(bytes32 => Signature[])) signatures; // sha3(metaid signed for) => sha3(item id digest) => signaturelist

	/**
	 * Add a new detached signature content hash to a metadata item content hash of a metaid
	 * @param _signer metaid of signer
	 * @param _target metaid of owner of metadata item
	 * @param _itemIdDigest metadata item id
	 * @param _itemDigest content hash of metadata item
	 * @param _signatureDigest detached signature content hash
	 */
	function setSignature(bytes32 _signer, bytes32 _target, bytes32 _itemIdDigest, bytes32 _itemDigest, bytes32 _signatureDigest) onlyowner {
		Signature memory s = Signature(_signer, _itemDigest, _signatureDigest);
		signatures[_target][_itemIdDigest].push(s);
	}

	/**
	 * Get number of members in signatures array for a metadata item of a metaid
	 * @param _target metaid of owner of metadata item
	 * @param _itemIdDigest metaidata item id
	 * @return number of signatures in array
	 */
	function getSignatureCount(bytes32 _target, bytes32 _itemIdDigest) constant returns (uint256) {
		bytes32 zero;
		require(_itemIdDigest != zero);
		return signatures[_target][_itemIdDigest].length;
	}

	/**
	 * Get signature at index in signature array for a metadata item of a metaid
	 * @param _target metaid of owner of metadata item
	 * @param _itemIdDigest metadata item id
	 * @param _idx index in signature array to detached signature content hash
	 * @return metaid of signer, metadata item content hash, detached signature content hash
	 */
	function getSignatureByIndex(bytes32 _target, bytes32 _itemIdDigest, uint32 _idx) constant returns (bytes32,bytes32,bytes32) {
		Signature storage s = signatures[_target][_itemIdDigest][_idx];
		return (s.signer, s.itemDigest, s.signatureDigest);
	}
}
