# `getMetadataSignatureCount(targetMetaId, metadataKeyHash)`

Get a META Identity metadata item's signature count.

## Parameters

- `targetMetaId` `<String>` - ENS namehash of Identity owner's META-ID
- `metadataKeyHash` `<String>` - SHA3 hash of metadata item key

## Returns

[Transaction object](http://web3js.readthedocs.io/en/1.0/web3-eth-contract.html#id12)
for the `getMetadataSignatureCount` method, which can then be called.

## Example

```js
import MetaId from 'meta-id'
import Web3 from 'web3'
// import META Identity contract addresses
import contractAddresses from '../contracts/addresses.json'

// init meta-id
const metaId = MetaId({ addresses: contractAddresses })
// init web3.js
const web3 = new Web3('http://localhost:8545')

// Ethereum account to send transactions from
const account = web3.eth.accounts.create()

const getMetadataSignatureCountTransaction = () => {
  // create transaction object
  const tx = metaId.getMetadataSignatureCount(
    metaId.generateMetaId('bob'), // for META-ID = `bob.id.meta`
    web3.utils.sha3('aux/twitter') // retrieve 'twitter' metadata item count
  )

  // call transaction
  return tx.call({ from: account.address, gas: 4700000 })
    .then(signatureCount => console.log(signatureCount))
}
```
