# `registerIdentity(label, address)`

Register a new META Identity.

## Parameters

- `label` `<String>` - SHA3 hash of Identity subdomain label to register
- `address` `<String>` - Ethereum address of the Identity owner

## Returns

[Transaction object](http://web3js.readthedocs.io/en/1.0/web3-eth-contract.html#id12)
for the `registerIdentity` method, which can then be encoded, signed and sent.

## Example

```js
import MetaId from 'meta-id'
import Web3 from 'web3'
// import META Identity contract addresses
import contractAddresses from '../contracts/addresses.json'

// init meta-id
const metaId = MetaId({ addresses: contractAddresses })
// init web3.js
const web3 = new Web3('http://localhost:8545')

// Ethereum account to send transactions from
const account = web3.eth.accounts.create()

const registerIdentityTransaction = () => {
  // create transaction object
  const tx = metaId.registerIdentity(
    web3.utils.sha3('alice'), // create META-ID = `alice.id.meta`
    account.address
  )

  // encode contract method ABI
  const abi = tx.encodeABI()

  // sign and send transaction
  return account.signTransaction({
    data: abi,
    gas: 4700000,
    to: contractAddresses.Identity,
  })
    .then(signedTxData =>
      web3.eth.sendSignedTransaction(signedTxData.rawTransaction)
    )
    .then(txReceipt => console.log(txReceipt))
}
```
