# `resolveIdentity(node)`

Retrieve a META Identity.

## Parameters

- `node` `<String>` - ENS namehash of Identity ENS node to resolve content from

## Returns

[Transaction object](http://web3js.readthedocs.io/en/1.0/web3-eth-contract.html#id12)
for the `resolveIdentity` method, which can then be called.

## Example

```js
import MetaId from 'meta-id'
import Web3 from 'web3'
// import META Identity contract addresses
import contractAddresses from '../contracts/addresses.json'

// init meta-id
const metaId = MetaId({ addresses: contractAddresses })
// init web3.js
const web3 = new Web3('http://localhost:8545')

// Ethereum account to send transactions from
const account = web3.eth.accounts.create()

const resolveIdentityTransaction = () => {
  // create transaction object
  const tx = metaId.resolveIdentity(
    metaId.generateMetaId('alice') // retrieve META-ID = `alice.id.meta`
  )

  // call transaction
  return tx.call({ from: account.address, gas: 4700000 })
    .then(metadataAddress => console.log(metadataAddress))
}
```
