# Architecture

The [META Identity](https://github.com/meta-network/docs/blob/master/concepts/identity.md)
implementation architecture is split into 3 levels:

<p align='center'>
  <img width="375" alt="Diagram of META Identity architecture"
  src="https://user-images.githubusercontent.com/1913316/29934705-0db757f2-8e74-11e7-8806-990f55505cdc.png">
</p>

## `meta-id` Library

The `meta-id` library exposes a set of methods that wrap the lower-level Smart
Contract ABIs and can be used to:
- Register new META Identities
- Retrieve existing META Identities
- Sign metadata belonging to META Identities
- Retrieve metadata signatures for META Identities

The aim of the library is to abstract some of the complexities
related to interacting with the Smart Contracts that application developers may
encounter.

There are other benefits to this approach:
- Simpler and safer to consume than direct contract import and manual addressing
- Increase developer accessibility - this is closer to the JS ecosystem norm of
  consuming libraries/APIs
- Provide utility methods that compliment the Smart Contracts
- Abstract some of the nuances of the web3.js API
  eg. `myContract.methods.myMethod([params])` becomes `myMethod(param1, param2)`
- Scope to evolve library into a consumable API over HTTP

## Smart Contracts

A set of Solidity contracts enforcing the
[META Identity specification](https://github.com/meta-network/docs/blob/master/concepts/identity.md)
for registering, retrieving and verifying identities.

## ÐApp/Web3.js

A Web3 ÐApp that utilises the `meta-id` library for managing META Identities is
expected to provide additional functionality to:
- Create and unlock Ethereum accounts
- Upload metadata to a decentralised storage system
- Generate detached cryptographic signatures of metadata
- Verify metadata signatures

The implementation of these additional features is left to the ÐApp to decide.
