/**
 This file is part of the meta-id library.

 Copyright (C) 2017 JAAK MUSIC LTD

 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU Lesser General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.

 If you have any questions please contact yo@jaak.io
 */

import namehash from 'eth-ens-namehash'

/**
 * Default META ID suffix
 *
 * @type {String}
 */
const META_ID_SUFFIX = 'id.meta'

/**
* Utility method to generate a META ID from a name
* using the ENS Namehash spec
*
* @see http://docs.ens.domains/en/latest/introduction.html#algorithm
*
* @param  {String} name Name to hash
* @return {String}      META ID (namehash)
*
* @example generateMetaId('alice')
* //=> '0x84e8b49dfdcd516a0e6f4484062c03e459c1d5a232469b99115b12c20251a1ce'
* //=> (alice.id.meta)
*/
const generateMetaId = name => {
  return namehash.hash(`${name}.${META_ID_SUFFIX}`)
}

export default generateMetaId
