/**
 This file is part of the meta-id library.

 Copyright (C) 2017 JAAK MUSIC LTD

 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU Lesser General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.

 If you have any questions please contact yo@jaak.io
 */

import { Identity } from './contracts/Identity.sol.js'

/**
 * Creates a transaction object for the `Identity.getSignatureByIndex` method.
 * This can be used to get a META Identity metadata item's signatures.
 *
 * @see http://web3js.readthedocs.io/en/1.0/web3-eth-contract.html#id12
 *
 * @example metaId.getMetadataSignatureByIndex(targetMetaId, metadataKeyHash, signatureIndex)
 *
 * @param  {bytes32} targetMetaId    ENS namehash of metadata owner's MetaID
 * @param  {bytes32} metadataKeyHash SHA3 hash of metadata item key
 * @param  {Number}  signatureIndex  Index of signature
 * @return {Promise}
 */
const getMetadataSignatureByIndex = (
  targetMetaId,
  metadataKeyHash,
  signatureIndex
) =>
  Identity.methods.getSignatureByIndex(
    targetMetaId,
    metadataKeyHash,
    signatureIndex
  )

export default getMetadataSignatureByIndex
