/**
 This file is part of the meta-id library.

 Copyright (C) 2017 JAAK MUSIC LTD

 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU Lesser General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.

 If you have any questions please contact yo@jaak.io
 */

import contracts from './contracts/index'
import events from './events'
import generateKeystoreFilename from './generateKeystoreFilename'
import generateMetaId from './generateMetaId'
import getMetadataSignatureByIndex from './getMetadataSignatureByIndex'
import getMetadataSignatureCount from './getMetadataSignatureCount'
import registerIdentity from './registerIdentity'
import resolveIdentity from './resolveIdentity'
import setMetadataContent from './setMetadataContent'
import setMetadataSignature from './setMetadataSignature'
import networks from './networks'

/**
 * Set contract addresses
 * @param {Object} [addresses] Locally deployed contract addresses
 * @param {String} [network]   Testnet deployed contracts to use
 */
const setContractAddress = ({ addresses, network }) => {
  if (addresses) {
    return Object.keys(addresses).map(
      contract =>
        contracts[contract] &&
        contracts[contract].setAddress(addresses[contract])
    )
  } else if (network) {
    return Object.keys(contracts).map(
      contract =>
        contracts[contract] &&
        contracts[contract].setAddress(networks[network][contract])
    )
  }
}

/**
 * META Identity constructor function
 *
 * @param  {Object} [opts]           Options
 * @param  {Object} [opts.addresses] Locally deployed contract addresses
 * @param  {Object} [opts.network]   Testnet in use
 * @return {Object}                  Library exports
 *
 * @example MetaId({ network: 'rinkeby' }) //=> use contracts deployed to Rinkeby testnet
 * @example MetaId({ addresses: { Identity: '0xe2e792511a19e1ddadc40305ca88b6cb7c3a1f27' } }) //=> use contracts deployed to local RPC node
 */
const MetaId = opts => {
  if (opts) setContractAddress(opts)

  return {
    events,
    generateKeystoreFilename,
    generateMetaId,
    getMetadataSignatureByIndex,
    getMetadataSignatureCount,
    registerIdentity,
    resolveIdentity,
    setMetadataContent,
    setMetadataSignature,
    version: () => VERSION,
  }
}

export default MetaId
