/**
 This file is part of the meta-id library.

 Copyright (C) 2017 JAAK MUSIC LTD

 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU Lesser General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.

 If you have any questions please contact yo@jaak.io
 */

import { Identity } from './contracts/Identity.sol.js'

/**
 * Creates a transaction object for the `Identity.setSignature` method.
 * This can be used to sign a META Identity metadata item.
 *
 * @see http://web3js.readthedocs.io/en/1.0/web3-eth-contract.html#id12
 *
 * @example metaId.setMetadataSignature(signerMetaId, targetMetaId, metadataKeyHash, metadataValueHash, signatureContentHash)
 *
 * @param  {bytes32} signerMetaId ENS namehash of metadata signer's MetaId
 * @param  {bytes32} targetMetaId ENS namehash of metadata owner's MetaId
 * @param  {bytes32} metadataKeyHash SHA3 hash of signed metadata item key
 * @param  {bytes32} metadataValueHash SHA3 hash of signed metadata item value
 * @param  {bytes32} signatureContentHash Content hash of detached signature
 * @return {Promise}
 */
const setMetadataSignature = (
  signerMetaId,
  targetMetaId,
  metadataKeyHash,
  metadataValueHash,
  signatureContentHash
) =>
  Identity.methods.setSignature(
    signerMetaId,
    targetMetaId,
    metadataKeyHash,
    metadataValueHash,
    signatureContentHash
  )

export default setMetadataSignature
